# mimepost

Mimepost - the Ruby gem for the mimepost

MimePost API for sending email. You can find out more about MimePost at [https://mimepost.com](http://mimepost.com). For this sample, you can use the api key `special-key` to test the authorization filters.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.1.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build mimepost.gemspec
```

Then either install the gem locally:

```shell
gem install ./mimepost-1.0.0.gem
```
(for development, run `gem install --dev ./mimepost-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'mimepost', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/mimepost/mimepost-ruby, then add the following in the Gemfile:

    gem 'mimepost', :git => 'https://github.com/mimepost/mimepost-ruby.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'mimepost'

# Setup authorization
Mimepost.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['X-Auth-Token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Auth-Token'] = 'Bearer'
end

api_instance = Mimepost::AccountsApi.new

begin
  #Get account profile details
  result = api_instance.account_profile_get
  p result
rescue Mimepost::ApiError => e
  puts "Exception when calling AccountsApi->account_profile_get: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.mimepost.com/v1/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Mimepost::AccountsApi* | [**account_profile_get**](docs/AccountsApi.md#account_profile_get) | **GET** /account/profile/ | Get account profile details
*Mimepost::AccountsApi* | [**account_profile_post**](docs/AccountsApi.md#account_profile_post) | **POST** /account/profile/ | Update account profile details
*Mimepost::AccountsApi* | [**settings_get**](docs/AccountsApi.md#settings_get) | **GET** /settings/ | Get all the settings
*Mimepost::AccountsApi* | [**settings_post**](docs/AccountsApi.md#settings_post) | **POST** /settings/ | Set a setting
*Mimepost::DomainsApi* | [**domains_get**](docs/DomainsApi.md#domains_get) | **GET** /domains/ | Get a list of all the domains
*Mimepost::DomainsApi* | [**domains_id_approve_post**](docs/DomainsApi.md#domains_id_approve_post) | **POST** /domains/{id}/approve/ | Submit request for the approval of a verified domain
*Mimepost::DomainsApi* | [**domains_id_delete**](docs/DomainsApi.md#domains_id_delete) | **DELETE** /domains/{id} | Remove a single domain
*Mimepost::DomainsApi* | [**domains_id_get**](docs/DomainsApi.md#domains_id_get) | **GET** /domains/{id} | Get the details of a single domain
*Mimepost::DomainsApi* | [**domains_id_verify_dkim_post**](docs/DomainsApi.md#domains_id_verify_dkim_post) | **POST** /domains/{id}/verify_dkim/ | Request for the verification of DKIM record for a single domain
*Mimepost::DomainsApi* | [**domains_id_verify_spf_post**](docs/DomainsApi.md#domains_id_verify_spf_post) | **POST** /domains/{id}/verify_spf/ | Request for the verification of SPF record for a single domain
*Mimepost::DomainsApi* | [**domains_id_verify_tracking_post**](docs/DomainsApi.md#domains_id_verify_tracking_post) | **POST** /domains/{id}/verify_tracking/ | Request for the verification of tracking record for a single domain
*Mimepost::DomainsApi* | [**domains_post**](docs/DomainsApi.md#domains_post) | **POST** /domains/ | Add single domain
*Mimepost::EmailsApi* | [**send_email**](docs/EmailsApi.md#send_email) | **POST** /emails/ | Send email
*Mimepost::StatsApi* | [**emaillogs_get**](docs/StatsApi.md#emaillogs_get) | **GET** /emaillogs/ | Get the logs of a particular date
*Mimepost::StatsApi* | [**stats_get**](docs/StatsApi.md#stats_get) | **GET** /stats/ | Get the summary of stats for a range of dates
*Mimepost::WebhooksApi* | [**webhooks_get**](docs/WebhooksApi.md#webhooks_get) | **GET** /webhooks/ | Get the list of all the webhooks
*Mimepost::WebhooksApi* | [**webhooks_id_delete**](docs/WebhooksApi.md#webhooks_id_delete) | **DELETE** /webhooks/{id} | Remove a single webhook
*Mimepost::WebhooksApi* | [**webhooks_id_get**](docs/WebhooksApi.md#webhooks_id_get) | **GET** /webhooks/{id} | Get the details of a single webhook
*Mimepost::WebhooksApi* | [**webhooks_id_put**](docs/WebhooksApi.md#webhooks_id_put) | **PUT** /webhooks/{id} | Update the details of a single webhook
*Mimepost::WebhooksApi* | [**webhooks_post**](docs/WebhooksApi.md#webhooks_post) | **POST** /webhooks/ | Add single webhook


## Documentation for Models

 - [Mimepost::AccountProfile](docs/AccountProfile.md)
 - [Mimepost::AccountProfileResponse](docs/AccountProfileResponse.md)
 - [Mimepost::AccountSettings](docs/AccountSettings.md)
 - [Mimepost::ApiResponse](docs/ApiResponse.md)
 - [Mimepost::ApiResponseAllWebhooks](docs/ApiResponseAllWebhooks.md)
 - [Mimepost::ApiResponseAllWebhooksData](docs/ApiResponseAllWebhooksData.md)
 - [Mimepost::ApiResponseDomainsList](docs/ApiResponseDomainsList.md)
 - [Mimepost::ApiResponseDomainsListData](docs/ApiResponseDomainsListData.md)
 - [Mimepost::ApiResponseEmaillogs](docs/ApiResponseEmaillogs.md)
 - [Mimepost::ApiResponseEmaillogsData](docs/ApiResponseEmaillogsData.md)
 - [Mimepost::ApiResponseSingleWebhooks](docs/ApiResponseSingleWebhooks.md)
 - [Mimepost::ApiResponseStats](docs/ApiResponseStats.md)
 - [Mimepost::ApiResponseStatsData](docs/ApiResponseStatsData.md)
 - [Mimepost::ApiResponseStatsDataDatewiseSummary](docs/ApiResponseStatsDataDatewiseSummary.md)
 - [Mimepost::ApiResponseStatsDataGraphSummary](docs/ApiResponseStatsDataGraphSummary.md)
 - [Mimepost::ApiResponseStatsDataTotalSummary](docs/ApiResponseStatsDataTotalSummary.md)
 - [Mimepost::ApiResponseStatsDataTotalSummaryStatus](docs/ApiResponseStatsDataTotalSummaryStatus.md)
 - [Mimepost::ApiResponseWebhooks](docs/ApiResponseWebhooks.md)
 - [Mimepost::ApiResponseWebhooksData](docs/ApiResponseWebhooksData.md)
 - [Mimepost::Domain](docs/Domain.md)
 - [Mimepost::Email](docs/Email.md)
 - [Mimepost::EmailAttachments](docs/EmailAttachments.md)
 - [Mimepost::EmailGlobalMergeVars](docs/EmailGlobalMergeVars.md)
 - [Mimepost::EmailMergeVars](docs/EmailMergeVars.md)
 - [Mimepost::EmailTo](docs/EmailTo.md)
 - [Mimepost::Webhook](docs/Webhook.md)
 - [Mimepost::Webhook1](docs/Webhook1.md)


## Documentation for Authorization


### api_key

- **Type**: API key
- **API key parameter name**: X-Auth-Token
- **Location**: HTTP header

